#[non_exhaustive]pub enum CheckIfServiceHasUsage {
Unspecified,
Skip,
Check,
UnknownValue(UnknownValue),
}Expand description
Enum to determine if service usage should be checked when disabling a service.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
When unset, the default behavior is used, which is SKIP.
Skip
If set, skip checking service usage when disabling a service.
Check
If set, service usage is checked when disabling the service. If a service, or its dependents, has usage in the last 30 days, the request returns a FAILED_PRECONDITION error.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using CheckIfServiceHasUsage::value or CheckIfServiceHasUsage::name.
Implementations